fs

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CopyFile added in v0.1.0

func CopyFile(src, dst string) error

CopyFile copies a file from source to destination

func IsExists

func IsExists(p string) (bool, error)

IsExists returns true if the given path exists. IsExists returns an error if it cannot determine whether the path exists

func IsNotExists

func IsNotExists(p string) bool

IsNotExists returns true if the given path does not exist or it is not accessible

func RemoveFile

func RemoveFile(p string) error

RemoveFile removes a file.

func RemoveTempDir

func RemoveTempDir() error

RemoveTempDir removes the temporary directory if it was created. This should be called via defer in main.go.

func WriteTempFile

func WriteTempFile(content string) (string, error)

WriteTempFile writes the given content to a newly created temp file. The caller is responsible for removing the created file and/or directory.

Types

This section is empty.

Jump to