Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsExists ¶
IsExists returns true if the given path exists. IsExists returns an error if it cannot determine whether the path exists
func IsNotExists ¶
IsNotExists returns true if the given path does not exist or it is not accessible
func RemoveTempDir ¶
func RemoveTempDir() error
RemoveTempDir removes the temporary directory if it was created. This should be called via defer in main.go.
func WriteTempFile ¶
WriteTempFile writes the given content to a newly created temp file. The caller is responsible for removing the created file and/or directory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.